<?php

if (!defined('ABSPATH')) {
    @require_once("../../../wp-config.php");
    status_header(404);
    nocache_headers();
    @include(get_404_template());
    exit();
}

define('CSYN_SPINNERCHIEF_OPTIONS', 'cxxx_spinnerchief_options');
define('CSYN_SPINREWRITER_OPTIONS', 'cxxx_spinrewriter_options');
define('CSYN_WORDAI_OPTIONS', 'cxxx_wordai_options');
define('CSYN_TBS_OPTIONS', 'cxxx_thebestspinner_options');
define('CSYN_HIDE_PASSWORDS', true);
define('CSYN_SPINNER_VERSION', 121);

function csyn_wordai($content) {
    $csyn_wa_options = get_option(CSYN_WORDAI_OPTIONS);
    $text = urlencode($content);
    if ($csyn_wa_options['plan'] == 'turing') {
        $ch = curl_init('http://wordai.com/users/turing-api.php');
        $quality = $csyn_wa_options['turing_quality'];
    } else {
        $ch = curl_init('http://wordai.com/users/regular-api.php');
        $quality = $csyn_wa_options['standard_quality'];
    }
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, "s=$text&quality=$quality&email=" . $csyn_wa_options['email'] . "&pass=" . $csyn_wa_options['pass'] .
            "&nonested=" . $csyn_wa_options['nonested'] . "&sentence=" . $csyn_wa_options['sentence'] . "&paragraph=" . $csyn_wa_options['returnspin'] .
            "&returnspin=" . $csyn_wa_options['returnspin'] . "&nooriginal=" . $csyn_wa_options['nooriginal'] .
            "&protected=" . urlencode($csyn_wa_options['protected']) . "&synonyms=" . urlencode($csyn_wa_options['synonyms']) . "&output=json");
    $response = trim(curl_exec($ch));
    curl_close($ch);
    $api_response_interpreted = json_decode($response, true);
    if ($api_response_interpreted['status'] == 'Success') {
        return $api_response_interpreted['text'];
    }
    return $content;
}

function csyn_spinnerchief($content) {
    $csyn_sc_options = get_option(CSYN_SPINNERCHIEF_OPTIONS);
    $url = '';
    foreach ($csyn_sc_options as $key => $option) {
        $url .= $key . '=' . urlencode($option) . "&";
    }
    $req = curl_init();
    curl_setopt($req, CURLOPT_URL, "http://api.spinnerchief.com:443/" . $url);
    curl_setopt($req, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($req, CURLOPT_POST, true);
    curl_setopt($req, CURLOPT_POSTFIELDS, base64_encode($content));
    $result = base64_decode(trim(curl_exec($req)));
    curl_close($req);
    if (strpos($result, 'error=') !== 0 && strlen($result)) {
        return $result;
    }
    return $content;
}

function csyn_spinrewriter($content) {
    $csyn_sr_options = get_option(CSYN_SPINREWRITER_OPTIONS);
    $data_raw = '';
    foreach ($csyn_sr_options as $key => $option) {
        if ($key != 'text_with_spintax') {
            $data_raw .= $key . '=' . urlencode($option) . '&';
        }
    }
    if (!isset($csyn_sr_options['text_with_spintax']) || $csyn_sr_options['text_with_spintax'] == 'false') {
        $data_raw .= 'action=unique_variation&text=' . urlencode($content);
    } else {
        $data_raw .= 'action=text_with_spintax&text=' . urlencode($content);
    }
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, "http://www.spinrewriter.com/action/api");
    curl_setopt($ch, CURLOPT_POST, true);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $data_raw);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    $response = trim(curl_exec($ch));
    curl_close($ch);
    $api_response_interpreted = json_decode($response, true);
    if ($api_response_interpreted['status'] == 'OK') {
        return $api_response_interpreted['response'];
    }
    return $content;
}

function csyn_tbs($content) {
    $csyn_tbs_options = get_option(CSYN_TBS_OPTIONS);
    $url = 'http://thebestspinner.com/api.php';
    $data = array();
    $data['action'] = 'authenticate';
    $data['format'] = 'php';
    $data['username'] = trim($csyn_tbs_options['username']);
    $data['password'] = trim($csyn_tbs_options['password']);
    $result = unserialize(csyn_curl_post($url, $data, $info));
    if (isset($result['success']) && $result['success'] == 'true') {
        $data['session'] = $result['session'];
        if ($csyn_tbs_options['text_with_spintax'] == 'true') {
            $data['action'] = 'identifySynonyms';
            $data['maxsyns'] = '10';
        } else {
            $data['action'] = 'rewriteText';
        }
        $data['protectedterms'] = $csyn_tbs_options['protectedterms'];
        $data['text'] = $content;
        $result = unserialize(csyn_curl_post($url, $data, $info));
        if ($result['success'] == 'true') {
            return $result['output'];
        }
    }
    return $content;
}

function csyn_spin_content($content, $mode) {
    global $csyn_syndicator;
    switch ($mode) {
        case '2':
            $content = csyn_spinnerchief($content);
            break;
        case '5':
            $content = csyn_spinrewriter($content);
            break;
        case '11':
            $content = csyn_tbs($content);
            break;
        case '14':
            $content = csyn_wordai($content);
            break;
    }
    return $content;
}

function csyn_spinners_dropbox($settings) {
    ?>
    <tr>
        <th scope = "row">Content spinner</th>
        <td><select name = "synonymizer_mode" size = "1">
                <?php
                echo '<option ' . (($settings["synonymizer_mode"] == "0") ? 'selected ' : '') . 'value="0">Don\'t spin content</option>';
                echo '<option ' . (($settings["synonymizer_mode"] == "2") ? 'selected ' : '') . 'value="2">Use SpinnerChief</option>';
                echo '<option ' . (($settings["synonymizer_mode"] == "5") ? 'selected ' : '') . 'value="5">Use SpinRewriter</option>';
                echo '<option ' . (($settings["synonymizer_mode"] == "11") ? 'selected ' : '') . 'value="11">Use TBS (TheBestSpinner)</option>';
                echo '<option ' . (($settings["synonymizer_mode"] == "14") ? 'selected ' : '') . 'value="14">Use WordAI</option>';
                ?>
            </select></td>
    </tr>
    <?php
}

function csyn_spinners_menu() {
    if (get_option(CSYN_WORDAI_OPTIONS) === false) {
        $options = array(
            'plan' => 'standard',
            'standard_quality' => '50',
            'turing_quality' => 'Readable',
            'email' => '',
            'pass' => '',
            'nonested' => '',
            'sentence' => 'on',
            'paragraph' => '',
            'returnspin' => 'true',
            'nooriginal' => 'on',
            'protected' => '',
            'synonyms' => '',
        );
        update_option(CSYN_WORDAI_OPTIONS, $options);
    }

    if (get_option(CSYN_SPINNERCHIEF_OPTIONS) === false) {
        $options = array(
            'spintype' => '1',
            'spinfreq' => '4',
            'autospin' => '1',
            'original' => '1',
            'wordscount' => '3',
            'usehurricane' => '0',
            'chartype' => '1',
            'convertbase' => '0',
            'onecharforword' => '0',
            'percent' => '0',
            'protecthtml' => '0',
            'spinhtml' => '0',
            'orderly' => '0',
            'wordquality' => '0',
            'username' => '',
            'password' => '',
            'apikey' => '150da559a18c40049',
            'protectwords' => '0',
            'querytimes' => '0',
            'replacetype' => '0',
            'pos' => '0',
            'UseGrammarAI' => '0',
            'rule' => 'none',
            'thesaurus' => 'English',
            'phrasecount' => '2',
            'tagprotect' => '[],<>'
        );
        update_option(CSYN_SPINNERCHIEF_OPTIONS, $options);
    }

    if (get_option(CSYN_SPINREWRITER_OPTIONS) === false) {
        $options = array(
            'text_with_spintax' => 'false',
            'email_address' => '',
            'api_key' => '',
            'auto_protected_terms' => 'false',
            'protected_terms' => '',
            'confidence_level' => 'medium',
            'auto_sentences' => 'false',
            'auto_paragraphs' => 'false',
            'auto_new_paragraphs' => 'false',
            'auto_sentence_trees' => 'false',
            'use_only_synonyms' => 'false',
            'nested_spintax' => 'false'
        );
        update_option(CSYN_SPINREWRITER_OPTIONS, $options);
    }

    if (get_option(CSYN_TBS_OPTIONS) === false) {
        $options = array(
            'username' => '',
            'password' => '',
            'protectedterms' => '',
            'text_with_spintax' => 'false'
        );
        update_option(CSYN_TBS_OPTIONS, $options);
    }

    $csyn_wa_options = get_option(CSYN_WORDAI_OPTIONS);
    $csyn_sc_options = get_option(CSYN_SPINNERCHIEF_OPTIONS);
    $csyn_sr_options = get_option(CSYN_SPINREWRITER_OPTIONS);
    $csyn_tbs_options = get_option(CSYN_TBS_OPTIONS);

    if (isset($_POST['submit_synonymizer_settings']) && check_admin_referer('synonymizer_settings')) {
        $csyn_wa_options['email'] = $_POST['wa_email'];
        $csyn_wa_options['pass'] = $_POST['wa_pass'];
        $csyn_wa_options['plan'] = $_POST['wa_plan'];
        $csyn_wa_options['standard_quality'] = $_POST['wa_standard_quality'];
        $csyn_wa_options['turing_quality'] = $_POST['wa_turing_quality'];
        $csyn_wa_options['nonested'] = @$_POST['wa_nonested'];
        $csyn_wa_options['sentence'] = @$_POST['wa_sentence'];
        $csyn_wa_options['paragraph'] = @$_POST['wa_paragraph'];
        (@$_POST['wa_returnspin'] == 'on') ? $csyn_wa_options['returnspin'] = 'true' : $csyn_wa_options['returnspin'] = '';
        $csyn_wa_options['nooriginal'] = @$_POST['wa_nooriginal'];
        $csyn_wa_options['protected'] = $_POST['wa_protected'];
        $csyn_wa_options['synonyms'] = $_POST['wa_synonyms'];
        update_option(CSYN_WORDAI_OPTIONS, $csyn_wa_options);

        $csyn_tbs_options['username'] = $_POST['tbs_username'];
        $csyn_tbs_options['password'] = $_POST['tbs_password'];
        $csyn_tbs_options['protectedterms'] = $_POST['tbs_protectedterms'];
        (@$_POST['tbs_text_with_spintax'] == 'on') ? $csyn_tbs_options['text_with_spintax'] = 'true' : $csyn_tbs_options['text_with_spintax'] = 'false';
        update_option(CSYN_TBS_OPTIONS, $csyn_tbs_options);

        $csyn_sc_options['spintype'] = $_POST['sc_spintype'];
        $csyn_sc_options['username'] = $_POST['sc_username'];
        $csyn_sc_options['password'] = $_POST['sc_password'];
        $csyn_sc_options['thesaurus'] = $_POST['sc_thesaurus'];
        $csyn_sc_options['spinfreq'] = $_POST['sc_spinfreq'];
        $csyn_sc_options['wordquality'] = $_POST['sc_wordquality'];
        $csyn_sc_options['original'] = $_POST['sc_original'];
        (@$_POST['sc_orderly'] == 'on') ? $csyn_sc_options['orderly'] = '1' : $csyn_sc_options['orderly'] = '0';
        $csyn_sc_options['protectwords'] = $_POST['sc_protectwords'];
        $csyn_sc_options['rule'] = $_POST['sc_rule'];
        $csyn_sc_options['replacetype'] = $_POST['sc_replacetype'];
        (@$_POST['sc_UseGrammarAI'] == 'on') ? $csyn_sc_options['UseGrammarAI'] = '1' : $csyn_sc_options['UseGrammarAI'] = '0';
        (@$_POST['sc_pos'] == 'on') ? $csyn_sc_options['pos'] = '1' : $csyn_sc_options['pos'] = '0';
        (@$_POST['sc_protecthtml'] == 'on') ? $csyn_sc_options['protecthtml'] = '1' : $csyn_sc_options['protecthtml'] = '0';
        $csyn_sc_options['tagprotect'] = $_POST['sc_tagprotect'];
        update_option(CSYN_SPINNERCHIEF_OPTIONS, $csyn_sc_options);

        $csyn_sr_options['email_address'] = $_POST['sr_email_address'];
        $csyn_sr_options['api_key'] = $_POST['sr_api_key'];
        $csyn_sr_options['protected_terms'] = $_POST['sr_protected_terms'];
        (@$_POST['sr_auto_protected_terms'] == 'on') ? $csyn_sr_options['auto_protected_terms'] = 'true' : $csyn_sr_options['auto_protected_terms'] = 'false';
        $csyn_sr_options['confidence_level'] = $_POST['sr_confidence_level'];
        (@$_POST['sr_auto_sentences'] == 'on') ? $csyn_sr_options['auto_sentences'] = 'true' : $csyn_sr_options['auto_sentences'] = 'false';
        (@$_POST['sr_auto_paragraphs'] == 'on') ? $csyn_sr_options['auto_paragraphs'] = 'true' : $csyn_sr_options['auto_paragraphs'] = 'false';
        (@$_POST['sr_auto_new_paragraphs'] == 'on') ? $csyn_sr_options['auto_new_paragraphs'] = 'true' : $csyn_sr_options['auto_new_paragraphs'] = 'false';
        (@$_POST['sr_auto_sentence_trees'] == 'on') ? $csyn_sr_options['auto_sentence_trees'] = 'true' : $csyn_sr_options['auto_sentence_trees'] = 'false';
        (@$_POST['sr_use_only_synonyms'] == 'on') ? $csyn_sr_options['use_only_synonyms'] = 'true' : $csyn_sr_options['use_only_synonyms'] = 'false';
        (@$_POST['sr_text_with_spintax'] == 'on') ? $csyn_sr_options['text_with_spintax'] = 'true' : $csyn_sr_options['text_with_spintax'] = 'false';
        (@$_POST['sr_nested_spintax'] == 'on') ? $csyn_sr_options['nested_spintax'] = 'true' : $csyn_sr_options['nested_spintax'] = 'false';
        update_option(CSYN_SPINREWRITER_OPTIONS, $csyn_sr_options);

        echo '<div id="message" class="updated fade"><p><strong>Settings saved.</strong></p></div>';
    }
    ?>
    <style type="text/css">
        div.cyberseo-ui-tabs-panel {
            margin: 0 5px 0 0px;
            padding: .5em .9em;
            height: 11em;
            width: 675px;
            overflow: auto;
            border: 1px solid #dfdfdf;
        }
        .error a {
            color: #100;
        }
    </style>

    <script type="text/javascript"
            src="//code.jquery.com/jquery-latest.min.js">
    </script>

    <script type="text/javascript">
        $(document).ready(function () {
            $(".tab_content").hide();
            $(".tab_content:first").show();
            $("ul.tabs li").click(function () {
                $("ul.tabs li").removeClass("active");
                $(this).addClass("active");
                $(".tab_content").hide();
                var activeTab = $(this).attr("rel");
                $("#" + activeTab).show();
            });
        });
    </script>

    <style type="text/css">
        ul.tabs {
            margin: 0;
            padding: 0;
            float: left;
            list-style: none;
            height: 32px;
            border-bottom: 1px solid #DDD;
            border-left: 1px solid #DDD;
            width: 100%;
        }
        ul.tabs li {
            float: left;
            margin: 0;
            cursor: pointer;
            padding: 0px 21px ;
            height: 31px;
            line-height: 31px;
            border: 1px solid #DDD;
            border-left: none;
            font-weight: bold;
            background: #EEE;
            overflow: hidden;
            position: relative;
        }
        ul.tabs li:hover {
            background: #DDD;
        }
        ul.tabs li.active{
            background: #FFF;
            border-bottom: 1px solid #FFF;
        }
        .tab_container {
            border-top: none;
            clear: both;
            float: left;
            width: 100%;
        }
        .tab_content {
            padding: 20px;
            display: none;
        }
    </style>

    <div class="wrap">
        <div class="metabox-holder postbox-container">
            <h2>Content Spinners</h2>

            <ul class="tabs">
                <li class="active" rel="wordai">WordAI</li>
                <li rel="spinnerchief">SpinnerChief</li>
                <li rel="spinrewriter">SpinRewriter</li>
                <li rel="tbs">TheBestSpinner</li>
            </ul>

            <form method="post" name="synonymizer">
                <div class="tab_container">

                    <div id="wordai" class="tab_content">
                        <table class="form-table">

                            <th scope="row">Account info</th>
                            <td>
                                <?php
                                echo 'Please enter your email and API key below or apply for your <a href="http://www.cyberseo.net/partners/wordai.php" target="_blank"><strong>WordAI</strong></a> account.';
                                ?>
                            </td>

                            <tr>
                                <th scope="row">Email</th>
                                <td>
                                    <input type="text" name="wa_email" size="40" value="<?php echo $csyn_wa_options['email']; ?>">
                                    <p class="description">your <strong>WordAI</strong> login email.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Pass</th>
                                <td>
                                    <input <?php
                                    if (CSYN_HIDE_PASSWORDS)
                                        echo 'type="password"';
                                    else
                                        echo 'type="text"';
                                    ?> name="wa_pass" size="40" value="<?php echo $csyn_wa_options['pass']; ?>">
                                    <p class="description">your <strong>WordAI</strong> password.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Plan</th>
                                <td>
                                    <select name="wa_plan" size="1">
                                        <?php
                                        echo '<option ' . (($csyn_wa_options['plan'] == "standard") ? 'selected ' : '') . 'value="standard">standard</option>';
                                        echo '<option ' . (($csyn_wa_options['plan'] == "turing") ? 'selected ' : '') . 'value="turing">turing</option>';
                                        ?>
                                    </select>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Standard Quality</th>
                                <td>
                                    <input type="text" name="wa_standard_quality" size="5" value="<?php echo $csyn_wa_options['standard_quality']; ?>">
                                    <p class="description">a numeric value between 0 and 100. The lower the number, the more unique, and the higher the number, the more readable. This option is used with Standard Plan only.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Turing Quality</th>
                                <td>
                                    <select name="wa_turing_quality" size="1">
                                        <?php
                                        echo '<option ' . (($csyn_wa_options['turing_quality'] == "Regular") ? 'selected ' : '') . 'value="Regular">Regular</option>';
                                        echo '<option ' . (($csyn_wa_options['turing_quality'] == "Unique") ? 'selected ' : '') . 'value="Unique">Unique</option>';
                                        echo '<option ' . (($csyn_wa_options['turing_quality'] == "Very Unique") ? 'selected ' : '') . 'value="Very Unique">Very Unique</option>';
                                        echo '<option ' . (($csyn_wa_options['turing_quality'] == "Readable") ? 'selected ' : '') . 'value="Readable">Readable</option>';
                                        echo '<option ' . (($csyn_wa_options['turing_quality'] == "Very Readable") ? 'selected ' : '') . 'value="Very Readable">Very Readable</option>';
                                        ?>
                                    </select>
                                    <p class="description">select the desired output quality depending on how readable vs unique you want your spin to be. This option is used with Turing Plan only.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">No Nested</th>
                                <td><input type="checkbox" name="wa_nonested"
                                    <?php
                                    if ($csyn_wa_options['nonested'] == 'on') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>enable it to turn off nested spinning (will help readability but hurt uniqueness).</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Sentence</th>
                                <td><input type="checkbox" name="wa_sentence"
                                    <?php
                                    if ($csyn_wa_options['sentence'] == 'on') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>enable it if you want paragraph editing, where WordAI will add, remove, or switch around the order of sentences in a paragraph (recommended!)</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Paragraph</th>
                                <td><input type="checkbox" name="wa_paragraph"
                                    <?php
                                    if ($csyn_wa_options['paragraph'] == 'on') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>enable it if you want WordAI to do paragraph spinning - perfect for if you plan on using the same Spintax many times.</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Return Spin</th>
                                <td><input type="checkbox" name="wa_returnspin"
                                    <?php
                                    if ($csyn_wa_options['returnspin'] == 'true') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>enable it if you want to just receive a spun version of the article you provided. Otherwise it will return Spintax. This option can be useful for generation of unique feeds in <a href="http://www.cyberseo.net/morphing-rss-host-mode-content-spinner/" target="_blank">Morphing RSS host mode</a>.</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">No Original</th>
                                <td><input type="checkbox" name="wa_nooriginal"
                                    <?php
                                    if ($csyn_wa_options['nooriginal'] == 'on') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>enable it if you do not want to include the original word in Spintax (if synonyms are found). This is the same thing as creating a "Super Unique" spin.</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Protected</th>
                                <td>
                                    <input type="text" name="wa_protected" size="40" value="<?php echo $csyn_wa_options['protected']; ?>">
                                    <p class="description">comma separated protected words (do not put spaces inbetween the words).</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Synonyms</th>
                                <td>
                                    <input type="text" name="wa_synonyms" size="40" value="<?php echo $csyn_wa_options['synonyms']; ?>">
                                    <p class="description">add your own synonyms (syntax: word1|synonym1,word two|first synonym 2|2nd syn). (comma separate the synonym sets and | separate the individuals synonyms).</p>
                                </td>
                            </tr>

                        </table>
                    </div>

                    <div id="spinnerchief" class="tab_content">
                        <table class="form-table">
                            <tr>
                                <th scope="row">Account info</th>
                                <td>
                                    <?php
                                    if ($csyn_sc_options['username'] != '' && $csyn_sc_options['password'] != '') {
                                        $data = $result = array();
                                        for ($i = 1; $i < 3; $i++) {
                                            $url = 'http://api.spinnerchief.com:443/apikey=' . urlencode($csyn_sc_options['apikey']) . '&username=' . urlencode($csyn_sc_options['username']) . '&password=' . urlencode($csyn_sc_options['password']) . '&querytimes=2';
                                            $result[] = base64_decode(trim(csyn_curl_post($url, $data, $info)));
                                        }
                                        echo 'Daily Limit: ' . $result[0] . '. Requests available: ' . $result[1] . '.';
                                    } else {
                                        echo 'Please enter your email and API key below or apply for your free <a href="http://www.cyberseo.net/partners/spinnerchief.php" target="_blank"><strong>SpinnerChief</strong></a> account.';
                                    }
                                    ?>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Username</th>
                                <td>
                                    <input type="text" name="sc_username" size="40" value="<?php echo $csyn_sc_options['username']; ?>">
                                    <p class="description">your <strong>SpinnerChief</strong> username.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Password</th>
                                <td>
                                    <input <?php
                                    if (CSYN_HIDE_PASSWORDS)
                                        echo 'type="password"';
                                    else
                                        echo 'type="text"';
                                    ?> name="sc_password" size="40" value="<?php echo $csyn_sc_options['password']; ?>">
                                    <p class="description">your <strong>SpinnerChief</strong> password.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Spin type</th>
                                <td>
                                    <select name="sc_spintype" size="1">
                                        <?php
                                        echo '<option ' . (($csyn_sc_options['spintype'] == "0") ? 'selected ' : '') . 'value="0">0</option>';
                                        echo '<option ' . (($csyn_sc_options['spintype'] == "1") ? 'selected ' : '') . 'value="1">1</option>';
                                        ?>
                                    </select>
                                    <label>when spin type = 0, SpinnerChief will return the spun article in Spintax format. When spin type = 1, SpinnerChief will return the spun article directly.</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Thesaurus</th>
                                <td>
                                    <input type="text" name="sc_thesaurus" size="40" value="<?php echo $csyn_sc_options['thesaurus']; ?>">
                                    <p class="description">the following rules are allowed: Arabic, Belarusian, Bulgarian, Croatian, Danish, Dutch, English, Filipino, Finnish, French, German,
                                        Greek, Hebrew,Indonesian, Italian, Lithuanian, Norwegian, Polish, Portuguese, Romanian, Slovak,
                                        Slovenian, Spanish, Swedish, Turkish, Vietnamese, users-defined thesaurus ID..</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Spin freq</th>
                                <td>
                                    <input type="text" name="sc_spinfreq" size="5" value="<?php echo $csyn_sc_options['spinfreq']; ?>">
                                    <label>the Spin Freq means word spin frequency, for example if Spin Freq = 1, every word will be spun, if Spin Freq = 3, 1/3 of all words will be spun, etc.</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Synonyms quality</th>
                                <td>
                                    <select name="sc_wordquality" size="1">
                                        <?php
                                        echo '<option ' . (($csyn_sc_options['wordquality'] == "0") ? 'selected ' : '') . 'value="0">Best Thesaurus to spin</option>';
                                        echo '<option ' . (($csyn_sc_options['wordquality'] == "1") ? 'selected ' : '') . 'value="1">Better Thesaurus to spin</option>';
                                        echo '<option ' . (($csyn_sc_options['wordquality'] == "2") ? 'selected ' : '') . 'value="2">Good Thesaurus to spin</option>';
                                        echo '<option ' . (($csyn_sc_options['wordquality'] == "3") ? 'selected ' : '') . 'value="3">All Thesaurus to spin</option>';
                                        echo '<option ' . (($csyn_sc_options['wordquality'] == "9") ? 'selected ' : '') . 'value="9">Everyone\'s favorite to spin</option>';
                                        ?>
                                    </select>
                                    <p class="description">define the synonym table quality.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Don't use original word</th>
                                <td>
                                    <select name="sc_original" size="1">
                                        <?php
                                        echo '<option ' . (($csyn_sc_options['original'] == "0") ? 'selected ' : '') . 'value="0">No</option>';
                                        echo '<option ' . (($csyn_sc_options['original'] == "1") ? 'selected ' : '') . 'value="1">Yes</option>';
                                        ?>
                                    </select>
                                    <p class="description">if "No", SpinnerChief will delete the original word in the return result.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Use synonyms orderly</th>
                                <td><input type="checkbox" name="sc_orderly"
                                    <?php
                                    if ($csyn_sc_options['orderly'] == '1') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>if checked, SpinnerChief uses the thesaurus randomly to spin. Otherwise the thesaurus will be used in it's listed order.</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Protect words</th>
                                <td>
                                    <input type="text" name="sc_protectwords" size="80" value="<?php echo $csyn_sc_options['protectwords']; ?>">
                                    <p class="description">when you set protectwords, the server will not spin words in the the protect words list, the format is word1,word2,word3,phrase1,phrase2.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Rule</th>
                                <td>
                                    <input type="text" name="sc_rule" size="40" value="<?php echo $csyn_sc_options['rule']; ?>">
                                    <p class="description">the following rules are allowed: arabic, belarusian, bulgarian,
                                        croatian, danish, dutch, english, filipino, finnish, french, german, greek, hebrew, indonesian, italian, lithuanian, norwegian, polish,  portuguese,romanian, slovak,
                                        slovenian, spanish, swedish, turkish, vietnamese, user-defined rule ID.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Replace type</th>
                                <td>
                                    <select name="sc_replacetype" size="1">
                                        <?php
                                        echo '<option ' . (($csyn_sc_options['replacetype'] == "0") ? 'selected ' : '') . 'value="0">Replace phrase and word</option>';
                                        echo '<option ' . (($csyn_sc_options['replacetype'] == "1") ? 'selected ' : '') . 'value="1">Only replace phrase</option>';
                                        echo '<option ' . (($csyn_sc_options['replacetype'] == "2") ? 'selected ' : '') . 'value="2">Only replace word</option>';
                                        echo '<option ' . (($csyn_sc_options['replacetype'] == "3") ? 'selected ' : '') . 'value="3">Replace phrase first, then replace word till the article passes copyscape';
                                        echo '<option ' . (($csyn_sc_options['replacetype'] == "4") ? 'selected ' : '') . 'value="4">Spin the article to most unique</option>';
                                        echo '<option ' . (($csyn_sc_options['replacetype'] == "5") ? 'selected ' : '') . 'value="5">Spin the article to most readable</option>';
                                        ?>
                                    </select>
                                    <p class="description">define the replace type.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Enable grammar AI</th>
                                <td><input type="checkbox" name="sc_UseGrammarAI"
                                    <?php
                                    if ($csyn_sc_options['UseGrammarAI'] == '1') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>if checked, the grammar correction will be performed.</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Enable POS</th>
                                <td><input type="checkbox" name="sc_pos"
                                    <?php
                                    if ($csyn_sc_options['pos'] == '1') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>if checked, the "part of speech" analysis will be performed.</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Do not protect HTML</th>
                                <td><input type="checkbox" name="sc_protecthtml"
                                    <?php
                                    if ($csyn_sc_options['protecthtml'] == '1') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>if checked, the SpinnerChief will not protect words in HTML tags in your article.</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Tag protect</th>
                                <td>
                                    <input type="text" name="sc_tagprotect" size="40" value="<?php echo $csyn_sc_options['tagprotect']; ?>">
                                    <p class="description">this will protect the text between tags. For example if you want to protect the text between[ and ], ( and ), <- and ->, use the following string: "[],(),<- ->".</p>
                                </td>
                            </tr>

                        </table>
                    </div>

                    <div id="spinrewriter" class="tab_content">
                        <table class="form-table">
                            <tr>
                                <th scope="row">Account info</th>
                                <td>
                                    <?php
                                    if ($csyn_sr_options['email_address'] == '' || $csyn_sr_options['api_key'] == '') {
                                        echo 'Please enter your email and API key below or apply for your <a href="http://www.cyberseo.net/partners/spinrewriter.php" target="_blank"><strong>SpinRewriter</strong></a> account.';
                                    } else {
                                        $url = 'http://www.spinrewriter.com/action/api';
                                        $data = array();
                                        $data['action'] = 'api_quota';
                                        $data['email_address'] = $csyn_sr_options['email_address'];
                                        $data['api_key'] = $csyn_sr_options['api_key'];
                                        $result = json_decode(csyn_curl_post($url, $data, $info), true);
                                        echo $result['response'];
                                    }
                                    ?>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Email address</th>
                                <td>
                                    <input type="text" name="sr_email_address" size="40" value="<?php echo $csyn_sr_options['email_address']; ?>">
                                    <p class="description">your <strong>SpinRewriter</strong> email address.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">API key</th>
                                <td>
                                    <input <?php
                                    if (CSYN_HIDE_PASSWORDS)
                                        echo 'type="password"';
                                    else
                                        echo 'type="text"';
                                    ?> name="sr_api_key" size="40" value="<?php echo $csyn_sr_options['api_key']; ?>">
                                    <p class="description">your <strong>SpinRewriter</strong> API key.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Protected terms</th>
                                <td>
                                    <textarea cols="90" rows="5" wrap="off" name="sr_protected_terms" style="margin:0;height:10em;width:100%;"><?php echo $csyn_sr_options['protected_terms']; ?></textarea><br />
                                    <p class="description">a list of keywords and key phrases that you do NOT want to spin. One term per line.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Auto protected terms</th>
                                <td><input type="checkbox" name="sr_auto_protected_terms"
                                    <?php
                                    if ($csyn_sr_options['auto_protected_terms'] == 'true') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>should SpinRewriter automatically protect all Capitalized Words except for those in the title of your original text?</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Confidence level</th>
                                <td>
                                    <select name="sr_confidence_level" size="1">
                                        <?php
                                        echo '<option ' . (($csyn_sr_options['confidence_level'] == "low") ? 'selected ' : '') . 'value="low">low </option>';
                                        echo '<option ' . (($csyn_sr_options['confidence_level'] == "medium") ? 'selected ' : '') . 'value="medium">medium </option>';
                                        echo '<option ' . (($csyn_sr_options['confidence_level'] == "high") ? 'selected ' : '') . 'value="high">high </option>';
                                        ?>
                                    </select>
                                    <label>the confidence level of the rewrite process.</label>
                                    <p class="description"><strong>low</strong>: largest number of synonyms for various words and phrases, least readable unique variations of text;<br />
                                        <strong>medium</strong>: relatively reliable synonyms, usually well readable unique variations of text (default setting);<br />
                                        <strong>high</strong>: only the most reliable synonyms, perfectly readable unique variations of text.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Auto sentences</th>
                                <td><input type="checkbox" name="sr_auto_sentences"
                                    <?php
                                    if ($csyn_sr_options['auto_sentences'] == 'true') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>should SpinRewriter spin complete sentences? If enabled, some sentences will be replaced with a (shorter) spun variation.</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Auto new paragraphs</th>
                                <td><input type="checkbox" name="sr_auto_new_paragraphs"
                                    <?php
                                    if ($csyn_sr_options['auto_new_paragraphs'] == 'true') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>should SpinRewriter automatically write additional paragraphs on its own? If enabled, the returned spun text will contain additional paragraphs.</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Auto sentence trees</th>
                                <td><input type="checkbox" name="sr_auto_sentence_trees"
                                    <?php
                                    if ($csyn_sr_options['auto_sentence_trees'] == 'true') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>if enabled, SpinRewriter will change "If he is hungry, John eats." to "John eats if he is hungry." and "John eats and drinks." to "John drinks and eats."</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Use only synonyms</th>
                                <td><input type="checkbox" name="sr_use_only_synonyms"
                                    <?php
                                    if ($csyn_sr_options['use_only_synonyms'] == 'true') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>if enabled, SpinRewriter will never use any of the original words of phrases if there is a synonym available. This significantly improves the uniqueness of generated spun content.</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Text with Spintax</th>
                                <td><input type="checkbox" name="sr_text_with_spintax"
                                    <?php
                                    if ($csyn_sr_options['text_with_spintax'] == 'true') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>if enabld SpinRewriter will return the spun article in Spintax format.</label>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Nested Spintax</th>
                                <td><input type="checkbox" name="sr_nested_spintax"
                                    <?php
                                    if ($csyn_sr_options['nested_spintax'] == 'true') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>if enabled, the returned spun text might contain 2 levels of nested spinning syntax.</label>
                                </td>
                            </tr>

                        </table>
                    </div>

                    <div id="tbs" class="tab_content">
                        <table class="form-table">
                            <tr>
                                <th scope="row">Account info</th>
                                <td>
                                    <?php
                                    $url = 'http://thebestspinner.com/api.php';
                                    $data = array();
                                    $data['action'] = 'authenticate';
                                    $data['format'] = 'php';
                                    $data['username'] = $csyn_tbs_options['username'];
                                    $data['password'] = $csyn_tbs_options['password'];
                                    $result = unserialize(csyn_curl_post($url, $data, $info, 10));
                                    if (isset($result['success']) && $result['success'] == 'true') {
                                        echo '<strong>TBS</strong> service is available.';
                                    } else {
                                        echo '<strong>TBS</strong> service is unavailable.';
                                        if (isset($result['error'])) {
                                            echo ' ' . $result['error'];
                                        }
                                    }
                                    if ($csyn_tbs_options['username'] == '' || $csyn_tbs_options['password'] == '') {
                                        echo ' Enter your username and password below or <a href="https://www.cyberseo.net/partners/tbs.php" target="_blank"><strong>apply for a TBS account</strong></a>.';
                                    }
                                    ?>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Username</th>
                                <td>
                                    <input type="text" name="tbs_username" size="40" value="<?php echo $csyn_tbs_options['username'];
                                    ?>">
                                    <p class="description">your <strong>TBS</strong> username.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Password</th>
                                <td>
                                    <input <?php
                                    echo 'type="text"';
                                    ?> name="tbs_password" size="40" value="<?php echo $csyn_tbs_options['password']; ?>">
                                    <p class="description">your <strong>TBS</strong> password.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Protected terms</th>
                                <td>
                                    <input type="text" name="tbs_protectedterms" size="40" value="<?php echo $csyn_tbs_options['protectedterms']; ?>">
                                    <p class="description">comma separated list of words and phrases you don't want replaced.</p>
                                </td>
                            </tr>

                            <tr>
                                <th scope="row">Text with Spintax</th>
                                <td><input type="checkbox" name="tbs_text_with_spintax"
                                    <?php
                                    if ($csyn_tbs_options['text_with_spintax'] == 'on') {
                                        echo "checked";
                                    }
                                    ?> />
                                    <label>if enabled, returns the processed spun text with Spintax. This option can be useful for generation of unique feeds in <a href="https://www.cyberseo.net/morphing-rss-host-mode-content-spinner/" target="_blank">Morphing RSS host mode</a>.</label>
                                </td>
                            </tr>

                        </table>
                    </div>

                </div>
                <div align="center">
                    <input type="submit" name="submit_synonymizer_settings" class="button-primary"
                           value="Update options" />&nbsp;&nbsp;<input type="button"
                           name="cancel" value="Cancel" class="button"
                           onclick="javascript:history.go(-1)" />
                </div>
                <?php wp_nonce_field('synonymizer_settings'); ?>
            </form>
        </div>
    </div>
    <?php
}
?>